diff tests/libclient/point/main.cpp @ 42:a47a4477f347

Misc: new style, closes #578
author David Demelier <markand@malikania.fr>
date Tue, 29 Nov 2016 21:21:36 +0100
parents d4f5f7231b84
children fabbe1759cec
line wrap: on
line diff
--- a/tests/libclient/point/main.cpp	Sun Nov 27 20:50:38 2016 +0100
+++ b/tests/libclient/point/main.cpp	Tue Nov 29 21:21:36 2016 +0100
@@ -1,5 +1,5 @@
 /*
  * main.cpp -- test Point
  *
  * Copyright (c) 2013-2016 Malikania Authors
  *
@@ -20,11 +20,11 @@
 
 #include <malikania/point.hpp>
 
-using namespace malikania;
+namespace mlk = malikania;
 
 TEST(Basics, none)
 {
-    Point point;
+    mlk::point point;
 
     ASSERT_EQ(0, point.x());
     ASSERT_EQ(0, point.y());
@@ -32,7 +32,7 @@
 
 TEST(Basics, standard)
 {
-    Point point(10, 20);
+    mlk::point point(10, 20);
 
     ASSERT_EQ(10, point.x());
     ASSERT_EQ(20, point.y());
@@ -40,23 +40,23 @@
 
 TEST(Basics, operatorEq)
 {
-    Point point1, point2;
+    mlk::point point1, point2;
 
     ASSERT_EQ(point1, point2);
 }
 
 TEST(Basics, operatorEq1)
 {
-    Point point1(10, 20);
-    Point point2(10, 20);
+    mlk::point point1(10, 20);
+    mlk::point point2(10, 20);
 
     ASSERT_EQ(point1, point2);
 }
 
 TEST(Basics, operatorNeq)
 {
-    ASSERT_NE(Point(10), Point(20));
-    ASSERT_NE(Point(10, 10), Point(10, 20));
+    ASSERT_NE(mlk::point(10), mlk::point(20));
+    ASSERT_NE(mlk::point(10, 10), mlk::point(10, 20));
 }
 
 int main(int argc, char **argv)
@@ -1,5 +1,5 @@
 /*
- * main.cpp -- test Point
+ * main.cpp -- test mlk::point
  *
  * Copyright (c) 2013-2016 Malikania Authors